---
title: Configuration
---

### Configuration

Below is the full configuration available with defaults values:

    "example" => [
        "type"   => "anomaly.field_type.state",
        "config" => [
            "default_value" => null,
            "top_options"   => null,
            "countries"     => null,
            "mode"          => "input",
            "handler"       => "Anomaly\StateFieldType\Handler\DefaultHandler@handle"
        ]
    ]

###### Configuration

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Example</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

default_value

</td>

<td>

IL

</td>

<td>

The default value.

</td>

</tr>

<tr>

<td>

countries

</td>

<td>

`["US", "CA", "MX"]`

</td>

<td>

The countries to display options for.

</td>

</tr>

<tr>

<td>

top_options

</td>

<td>

`["IL", "IA", "WI"]`

</td>

<td>

The top `dropdown` options.

</td>

</tr>

<tr>

<td>

mode

</td>

<td>

dropdown

</td>

<td>

The input mode. Valid options are `input` and `dropdown`.

</td>

</tr>

<tr>

<td>

handler

</td>

<td>

`App\Example\MyStates@handle`

</td>

<td>

The options handler.

</td>

</tr>

</tbody>

</table>

#### Addon Configuration

The state options are controlled by the Streams Platform `states/*` configuration files. State configuration files are named by country code.

You can override these options by publishing the Streams Platform with:

    php artisan streams:publish

<div class="alert alert-success">**Contribute:** If you have states to add or have found an error, submit a pull request to [https://github.com/anomalylabs/streams-platform](https://github.com/anomalylabs/streams-platform)</div>

#### Option Handlers

Option handlers are responsible for setting the available state options on the field type. You can define your own option handler to add your own logic to available options.

You can define custom handlers as a callable string where `@handle will be assumed if no method is provided:

    "handler" => "App/Example/MyStates@handle"

Option handlers can also a handler with a closure:

    "example" => [
        "config" => [
            "handler" => function (StateFieldType $fieldType) {
                $fieldType->setOptions(
                    [
                        "IL" => config("streams::states/US.available.IL.name"),
                        "IA" => config("streams::states/US.available.IA.name")
                    ]
                );
            }
        ]
    ]

<div class="alert alert-info">**Remember:** Closures can not be stored in the database so your closure type handlers must be set / overridden from the form builder.</div>

##### Writing Option Handlers

Writing custom option handlers is easy. To begin create a class with the method you defined in the config option.

    "handler" => "App/Example/MyStates@handle"

The handler string is called via Laravel's service container. The `StateFieldType $fieldType` is passed as an argument.

<div class="alert alert-primary">**Pro Tip:** Handlers are called through Laravel's service container so method and class injection is supported.</div>

    <?php namespace App\Example;

    class MyStates
    {
        public function handle(StateFieldType $fieldType)
        {
            $fieldType->setOptions(
                [
                    "IL" => config("streams::states/US.available.IL.name"),
                    "IA" => config("streams::states/US.available.IA.name")
                ]
            );
        }
    }
